@@ -13,6 +13,8 @@ import tabulate
 import tqdm
 
 import sdgym
+from sdgym.synthesizers.base import Baseline
+from sdgym.utils import get_synthesizers
 
 
 def _env_setup(logfile, verbosity):
@@ -134,6 +136,11 @@ def _list_available(args):
     _print_table(datasets, args.sort, args.reverse, {'size': humanfriendly.format_size})
 
 
+def _list_synthesizers(args):
+    synthesizers = Baseline.get_baselines()
+    _print_table(pd.DataFrame(get_synthesizers(list(synthesizers))))
+
+
 def _collect(args):
     sdgym.collect.collect_results(args.input_path, args.output_file, args.aws_key, args.aws_secret)
 
@@ -241,6 +248,11 @@ def _get_parser():
     list_available.add_argument('-as', '--aws-secret', type=str, required=False,
                                 help='Aws secret access key to use when reading datasets.')
 
+    # list-synthesizers
+    list_available = action.add_parser('list-synthesizers',
+                                       help='List synthesizers available for use.')
+    list_available.set_defaults(action=_list_synthesizers)
+
     # collect
     collect = action.add_parser('collect', help='Collect sdgym results.')
     collect.set_defaults(action=_collect)
