@@ -1,7 +1,9 @@
 """Random utils used by SDGym."""
 
+import copy
 import importlib
 import json
+import logging
 import os
 import sys
 import traceback
@@ -14,6 +16,8 @@ from sdgym.errors import SDGymError
 from sdgym.synthesizers.base import Baseline
 from sdgym.synthesizers.utils import select_device
 
+LOGGER = logging.getLogger(__name__)
+
 
 def used_memory():
     """Get the memory used by this process nicely formatted."""
@@ -74,17 +78,27 @@ def _get_synthesizer(synthesizer, name=None):
 
     if isinstance(synthesizer, str):
         if synthesizer.endswith('.json'):
+            LOGGER.info('Trying to load synthesizer from a JSON file.')
             with open(synthesizer, 'r') as json_file:
                 return json.load(json_file)
 
-        baselines = Baseline.get_subclasses()
+        baselines = Baseline.get_subclasses(include_parents=True)
         if synthesizer in baselines:
+            LOGGER.info('Trying to import synthesizer by name.')
             synthesizer = baselines[synthesizer]
+
         else:
             try:
-                synthesizer = import_object(synthesizer)
+                LOGGER.info('Trying to load synthesizer from JSON string.')
+                return json.loads(synthesizer)
+
             except Exception:
-                raise SDGymError(f'Unknown synthesizer {synthesizer}') from None
+                try:
+                    LOGGER.info('Trying to import synthesizer from fully qualified name.')
+                    synthesizer = import_object(synthesizer)
+
+                except Exception:
+                    raise SDGymError(f'Unknown synthesizer {synthesizer}') from None
 
     if not name:
         name = _get_synthesizer_name(synthesizer)
@@ -92,11 +106,11 @@ def _get_synthesizer(synthesizer, name=None):
     return {
         'name': name,
         'synthesizer': synthesizer,
-        'modalities': getattr(synthesizer, 'MODALITIES', None),
+        'modalities': getattr(synthesizer, 'MODALITIES', []),
     }
 
 
-def get_synthesizers_dict(synthesizers):
+def get_synthesizers(synthesizers):
     """Get the dict of synthesizers from the input value.
 
     If the input is a synthesizer or an iterable of synthesizers, get their names
@@ -137,7 +151,7 @@ def _get_kwargs(synthesizer_dict, method_name, replace):
     method_kwargs = synthesizer_dict.get(method_name + '_kwargs', {})
     for key, value in method_kwargs.items():
         for replace_keyword, replace_value in replace:
-            if value == replace_keyword:
+            if isinstance(value, type(replace_keyword)) and value == replace_keyword:
                 method_kwargs[key] = replace_value
 
     return method_kwargs
@@ -151,7 +165,7 @@ def build_synthesizer(synthesizer, synthesizer_dict):
         * ``init``: Dict with the keyword arguments to pass to the ``__init__`` method. The
           arguments should include the metadata, real data or device arguments when
           required, encoded as the corresponding keywords.
-        * ``init``: Dict with the keyword arguments to pass to the ``fit`` method. The
+        * ``fit``: Dict with the keyword arguments to pass to the ``fit`` method. The
           arguments should include the metadata, real data or device arguments when
           required, encoded as the corresponding keywords.
         * ``modalities``: List of modalities supported by this synthesizer.
@@ -174,14 +188,17 @@ def build_synthesizer(synthesizer, synthesizer_dict):
         callable:
             The synthesizer function
     """
+
+    _synthesizer_dict = copy.deepcopy(synthesizer_dict)
+
     def _synthesizer_function(real_data, metadata):
-        metadata_keyword = synthesizer_dict.get('metadata', '$metadata')
-        real_data_keyword = synthesizer_dict.get('real_data', '$real_data')
-        device_keyword = synthesizer_dict.get('device', '$device')
-        device_attribute = synthesizer_dict.get('device_attribute')
+        metadata_keyword = _synthesizer_dict.get('metadata', '$metadata')
+        real_data_keyword = _synthesizer_dict.get('real_data', '$real_data')
+        device_keyword = _synthesizer_dict.get('device', '$device')
+        device_attribute = _synthesizer_dict.get('device_attribute')
         device = select_device()
 
-        multi_table = 'multi-table' in synthesizer_dict['modalities']
+        multi_table = 'multi-table' in _synthesizer_dict['modalities']
         if not multi_table:
             table = metadata.get_tables()[0]
             metadata = metadata.get_table_meta(table)
@@ -193,8 +210,8 @@ def build_synthesizer(synthesizer, synthesizer_dict):
             (device_keyword, device),
         ]
 
-        init_kwargs = _get_kwargs(synthesizer_dict, 'init', replace)
-        fit_kwargs = _get_kwargs(synthesizer_dict, 'fit', replace)
+        init_kwargs = _get_kwargs(_synthesizer_dict, 'init', replace)
+        fit_kwargs = _get_kwargs(_synthesizer_dict, 'fit', replace)
 
         instance = synthesizer(**init_kwargs)
         if device_attribute:
